*This do-file cleans nonfood consumption data

*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}
set more off, perm

use "${gsdData}\1-CleanInput\nonfood.dta", clear
*Add variable on household module assignment
merge m:1 state ea hh using "${gsdData}\1-CleanInput\hhq.dta", keepusing(mod_hh) assert(match master) keep(match master) nogen
	
********************************************************************************
* Cleaning: Tagging of outliers
********************************************************************************
* Cleaning Rule: 
* i) Tag items higher than hard constraint
gen tag_beyond_hard_max = .
replace tag_beyond_hard_max= 0 if cons==1
replace tag_beyond_hard_max  = 1 if cons==1 & price>c_max_h  & price!=. 
* ii) Tag items less than hard constraint
gen tag_beyond_hard_min = . 
replace tag_beyond_hard_min= 0 if cons==1 
replace tag_beyond_hard_min= 1 if cons==1 & price<c_min_h & price!=.
* iii) Tag items with price == 0 
gen tag_zero_price = . 
replace tag_zero_price = 0 if cons==1
replace tag_zero_price = 1 if cons==1 & price == 0 
* iv) Tag items that were consumed but have missing price
gen tag_missing_price = . 
replace tag_missing_price = 0 if cons==1
replace tag_missing_price = 1 if cons==1 & price == . 
* Check how many items are affected by hard max and hard min price tags
tabstat price if tag_beyond_hard_min==1, by(itemlabel) stat(N mean min q max)
tabstat price if tag_beyond_hard_max==1, by(itemlabel) stat(N mean min q max)

********************************************************************************
* Cleaning: Replacement of outliers
********************************************************************************
set more off, permanently 
*Calculate medians at various geographical levels
bysort itemid state ea: egen price_state_ea = median(price)
bysort itemid state ea: egen price_state_ea_c = count(price)
bysort itemid state urban: egen price_state_urban = median(price)
bysort itemid state urban: egen price_state_urban_c = count(price)
bysort itemid : egen price_national = median(price)
* Replace outliers with median prices as calculated above
* Use median prices from smallest geo level where min # of 10 obs are available
gen price_cleaned = price if (cons==1) 
local varlist "tag_beyond_hard_max tag_beyond_hard_min tag_zero_price tag_missing_price"
foreach t of local varlist{
	replace  price_cleaned =  price_national if (`t'==1)  										
	replace  price_cleaned =  price_state_urban if (`t'==1 &  price_state_urban_c>=10)
	replace  price_cleaned =  price_state_ea if (`t'==1 &  price_state_ea_c>=6)
}
*Turn any USD prices into SSP using 2.95 as exchange rate
replace price = price*2.95 if curr==1

********************************************************************************
* Consistency checks
********************************************************************************
*Check effect of cleaning on price variables:
tabstat price price_cleaned, stat(N sd mean min q max)
*Replace price variable with cleaned price variable
drop price
rename price_cleaned price
label var price "How much did you spend on this item?"
mean price 
*Transform annual consumptions into monthly consumptions 
replace price = price/12 if recall==365 & cons==1
mean price
*Transform monthly consumptions into weekly consumptions
replace price = price*12/365.25*7 if cons==1 
mean price
*Calculate cons value
gen cons_value = price
replace cons_value = 0 if missing(cons_value) & mod_item == 0 
replace cons_value = 0 if missing(cons_value) & mod_item == 1 & mod_hh == 1
replace cons_value = 0 if missing(cons_value) & mod_item == 2 & mod_hh == 2
replace cons_value = 0 if missing(cons_value) & mod_item == 3 & mod_hh == 3
replace cons_value = 0 if missing(cons_value) & mod_item == 4 & mod_hh == 4 
*Drop tags
drop tag* *_state* price_national 
*Set cons_value to missing where cons==.
replace cons_value = . if missing(cons)
*Drop missing values 
drop if missing(cons)
*Temp save 
save "${gsdTemp}/nonfood_predropfood.dta", replace 
use "${gsdTemp}/nonfood_predropfood.dta", replace 
*Drop households without core food cons 
merge m:1 state ea hh using "${gsdData}\1-CleanTemp\cons_hh0.dta", keepusing(cons_hh0) keep(match master) assert(match master)
drop if cons_hh0 == 0 | missing(cons_hh0)
drop cons_hh0 _merge
*Add label for cons_value
label var cons_value "What was the amount consumed per week in SSP?"
* Save dataset
save "${gsdData}/1-CleanTemp/nonfood.dta", replace 

********************************************************************************
* Calculate hh aggregates 
********************************************************************************
*Calculate weekly hh consumption aggregates for each module
forval i=0/3 {
	*Load nonfood.dta data
	use "${gsdData}/1-CleanTemp/nonfood.dta", clear
	*Collapse on hh level for modules 0-3
	collapse weight mod_item mod_hh (sum) cons_value if mod_item == `i' , by(state ea hh)
	rename cons_value nonfood_opt`i'_hh_wk
	save "${gsdTemp}/nonfood_opt`i'_hh_wk.dta", replace
}
* Merge into one dataset 
use "${gsdTemp}/nonfood_opt0_hh_wk.dta", clear
forval i=1/3{
	merge 1:1 state ea hh  using "${gsdTemp}/nonfood_opt`i'_hh_wk.dta", keepusing(nonfood_opt`i'_hh_wk) keep(match master) assert(match master) nogen
}	
*Temp save
save "${gsdTemp}/nonfood_pre_mod4.dta", replace
*Run do file that imputes share for module 4
do  "${gsdDo}/1-1-3-2-clean-nonfood_impute_mod4.do"
*Load data 
use "${gsdTemp}/nonfood_pre_mod4", clear
*Add calculated share for module 4 because of erroneous assignment in questionnaire
*The share of module 4 is calculated as a share of the core and based on the 
*NBHS 2009. The share of module 4 / core are 11.9616%
gen nonfood_opt4_hh_wk = nonfood_opt0_hh_wk * 0.119616 //if mod_hh == 4
*Only for the purpose of the imputation, we leave in the share of module 4 for 
*all households, even those not assigned module 4 questions
*Replace missing values with zeros where no items were consumed
replace nonfood_opt1_hh_wk = 0 if nonfood_opt1_hh_wk  == . & mod_hh == 1
replace nonfood_opt2_hh_wk = 0 if nonfood_opt2_hh_wk  == . & mod_hh == 2
replace nonfood_opt3_hh_wk = 0 if nonfood_opt3_hh_wk  == . & mod_hh == 3
*Set to missing any non-food cons where FOOD core cons was == 0 or . 
merge m:1 state ea hh using  "${gsdData}/1-CleanTemp/hh_food.dta", keepusing(food_opt0_hh_wk) assert(match master) keep(match master)
forvalues i = 0/4 {
	replace nonfood_opt`i'_hh_wk = . if (food_opt==0 | missing(food_opt))
}
drop _merge food_opt0_hh_wk

*Check for consistency
tabstat nonfood_opt?_hh_wk, stat(n mean)

********************************************************************************
* Save dataset with hh aggregates 
********************************************************************************
*Drop redundant variables
drop weight mod_hh
*Save as nonfood_aggregates in 1-CleanTemp folder 
save "${gsdData}/1-CleanTemp/hh_nonfood.dta", replace 
*Finish item shares for 2015 
*Load 2015 data
use "${gsdData}/1-CleanTemp/nonfood.dta", clear
*Merge core household aggregates
merge m:1 state ea hh using "${gsdData}/1-CleanTemp/hh_nonfood.dta", keepusing(nonfood_opt0_hh_wk) nogen keep(match master)
*Calculate shares of core for each item from 2009 dataset
gen x = cons_value / nonfood_opt0_hh_wk  
bysort itemid: egen share_of_core = mean(x)
collapse share_of_core [pweight=weight], by(itemid)
export excel using "${gsdOutput}/shares.xls", sheet("Raw_NF_2015_Itemshares") sheetreplace firstrow(var)

********************************************************************************
* Calculate deflator
********************************************************************************
*Calculate deflator
do "${gsdDo}/1-1-3-1-clean-nonfood_food_deflator.do"
